@@ -269,6 +269,7 @@ public:
   }
 
   void finish(long read_req, long dram_cycles) {
+    ostream &out = Stats::statlist.stat_output;
     read_latency_avg = read_latency_sum.value() / read_req;
     req_queue_length_avg = req_queue_length_sum.value() / dram_cycles;
     read_req_queue_length_avg = read_req_queue_length_sum.value() / dram_cycles;
@@ -278,14 +279,14 @@ public:
     double bw =
         (read_transaction_bytes.value() + write_transaction_bytes.value()) /
         (active_clk);
-    std::cout << " channel " << channel->id << " MLP  "
-              << (double)req_queue_length_sum.value() / active_clk;
-    std::cout << "  BLP " << (double)sum_blp / blp_clk << "  bw " << bw;
-    // std::cout<< "  active_clk "<<active_clk<<"  blp_clk "<<blp_clk;
-    std::cout << " A-rate " << (double)active_clk / clk << " A-rate1 "
-              << (double)channel->active_cycles.value() / clk;
-    std::cout << " readBytes " << read_transaction_bytes.value()
-              << " writeBytes " << write_transaction_bytes.value() << "\n";
+    out << " channel " << channel->id << " MLP  "
+        << (double)req_queue_length_sum.value() / active_clk;
+    out << "  BLP " << (double)sum_blp / blp_clk << "  bw " << bw;
+    // out<< "  active_clk "<<active_clk<<"  blp_clk "<<blp_clk;
+    out << " A-rate " << (double)active_clk / clk << " A-rate1 "
+        << (double)channel->active_cycles.value() / clk;
+    out << " readBytes " << read_transaction_bytes.value() << " writeBytes "
+        << write_transaction_bytes.value() << "\n";
 
     // call finish function of each channel
     channel->finish(dram_cycles);
