@@ -35,7 +35,7 @@ public:
   virtual void tick() = 0;
   virtual bool send(Request req) = 0;
   virtual int getBankID() = 0;
-  virtual unsigned get_channel_id(uint64_t addr)=0;
+  virtual unsigned get_channel_id(uint64_t addr) = 0;
   virtual int pending_requests() = 0;
   virtual void finish() = 0;
   virtual long page_allocator(long addr, int coreid) = 0;
@@ -132,7 +132,7 @@ public:
     }
 
     int type_in = configs.get_addr_mapping();
-    std::cout << "addr_mapping is " << type_in << std::endl;
+    // std::cout << "addr_mapping is " << type_in << std::endl;
     switch (type_in) {
     case 0:
       type = Type::ChRaBaRoCo;
@@ -290,13 +290,11 @@ public:
   }
 
   int getBankID() override { return bank_id; }
-  unsigned get_channel_num() {
-    return 8;
-  }
+  unsigned get_channel_num() { return 8; }
   unsigned get_channel_id(uint64_t taddr) override {
-    long addr=(long)taddr;
-    auto req=Request(addr,Request::Type::READ);
-    int channel_id=0;
+    long addr = (long)taddr;
+    auto req = Request(addr, Request::Type::READ);
+    int channel_id = 0;
     if (use_mapping_file) {
       apply_mapping(addr, req.addr_vec);
     } else {
@@ -304,7 +302,7 @@ public:
       case int(Type::ChRaBaRoCo):
         for (int i = addr_bits.size() - 1; i >= 1; i--)
           slice_lower_bits(addr, addr_bits[i]);
-        channel_id=slice_lower_bits(addr, addr_bits[0]);
+        channel_id = slice_lower_bits(addr, addr_bits[0]);
         break;
       case int(Type::RoBaRaCoCh):
         channel_id = slice_lower_bits(addr, addr_bits[0]);
@@ -321,7 +319,6 @@ public:
         channel_id = slice_lower_bits(addr, addr_bits[0]);
         // rank
 
-
         break;
 
       default:
@@ -339,7 +336,7 @@ public:
     // Each transaction size is 2^tx_bits, so first clear the lowest tx_bits
     // bits
     clear_lower_bits(addr, tx_bits);
-    auto bank=0;
+    auto bank = 0;
     if (use_mapping_file) {
       apply_mapping(addr, req.addr_vec);
     } else {
@@ -382,9 +379,9 @@ public:
 
         req.addr_vec[(int)T::Level::Bank] =
             slice_lower_bits(addr, addr_bits[(int)T::Level::Bank]);
-        bank=req.addr_vec[(int)T::Level::Bank];
+        bank = req.addr_vec[(int)T::Level::Bank];
         // Col
-        if(bank<0 or bank>16){
+        if (bank < 0 or bank > 16) {
           throw;
         }
         req.addr_vec[(int)T::Level::Column] =
@@ -424,7 +421,7 @@ public:
     return false;
   }
 
-  void init_mapping_with_file(const string& filename) {
+  void init_mapping_with_file(const string &filename) {
     ifstream file(filename);
     assert(file.good() && "Bad mapping file");
     // possible line types are:
@@ -511,19 +508,20 @@ public:
   }
 
   void dump_mapping_scheme() {
-    cout << "Mapping Scheme: " << endl;
+    ostream &out = Stats::statlist.stat_output;
+    out << "Mapping Scheme: " << endl;
     for (MapScheme::iterator mapit = mapping_scheme.begin();
          mapit != mapping_scheme.end(); mapit++) {
       int level = mapit->first;
       for (MapSchemeEntry::iterator entit = mapit->second.begin();
            entit != mapit->second.end(); entit++) {
-        cout << T::level_str[level] << "[" << entit->first << "] := ";
-        cout << "PhysicalAddress[" << *(entit->second.begin()) << "]";
+        out << T::level_str[level] << "[" << entit->first << "] := ";
+        out << "PhysicalAddress[" << *(entit->second.begin()) << "]";
         entit->second.erase(entit->second.begin());
         for (MapSrcVector::iterator it = entit->second.begin();
              it != entit->second.end(); it++)
-          cout << " xor PhysicalAddress[" << *it << "]";
-        cout << endl;
+          out << " xor PhysicalAddress[" << *it << "]";
+        out << endl;
       }
     }
   }
